Documentation
¶
Index ¶
- func RenderWith(k8s *kube.K8s) template.FuncMap
- type Depends
- type Jobs
- type Node
- type Resource
- type Stage
- type Stages
- func (stg *Stages) Connect(k8s *kube.K8s, tiller *helm.Tiller, input util.Values) error
- func (stg *Stages) Destroy(input util.Values, force bool)
- func (stg *Stages) Lint(in util.Values) (err error)
- func (stg *Stages) NewDepends(reverse bool) *Depends
- func (stg *Stages) Run(input util.Values, force bool) error
- func (stg *Stages) Until(input util.Values, force bool, target string)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Depends ¶
Depends implements a mapped waitgroup for dependencies
type Resource ¶ added in v0.2.0
type Resource interface {
Lint(string, *util.Values) error
Status() (bool, error)
Install() error
Upgrade() error
Delete() error
Connect(interface{})
SetInput([]byte)
GetInput() []byte
}
Resource is the thing to be created / destroyed
type Stage ¶
type Stage struct {
Depends []string `yaml:"depends"` // dependencies
Forget bool `yaml:"forget"` // install only
Template string `yaml:"template"` // template file
Jobs Jobs `yaml:"jobs"` // bash jobs
Kind string `yaml:"kind"` // type of deploy
Requires util.Values `yaml:"requires"` // env requirements
Values interface{} `yaml:"values"` // yaml values
Resource
}
Stage represents a single part of the deployment pipeline
func (*Stage) UnmarshalYAML ¶ added in v0.2.0
UnmarshalYAML allows us to determine the type of our resource
type Stages ¶ added in v0.2.0
Stages represents the complete workflow.
func (*Stages) Connect ¶ added in v0.2.0
Connect links all of our stages to their required resources and pre-renders their input
func (*Stages) NewDepends ¶ added in v0.3.5
NewDepends generates a dependency map
Click to show internal directories.
Click to hide internal directories.