helm

package
v0.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2019 License: GPL-3.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Chart

type Chart struct {
	Name       string `yaml:"name"`       // name of chart
	Repository string `yaml:"repository"` // chart repository
	Version    string `yaml:"version"`    // chart version
	Release    string `yaml:"release"`    // release name
	Namespace  string `yaml:"namespace"`  // namespace
	Timeout    int64  `yaml:"timeout"`    // install / upgrade wait time
	Object     []byte
	*Tiller
}

Chart comprises the helm release

func (*Chart) Connect added in v0.2.0

func (c *Chart) Connect(bridge interface{})

Connect sets the established helm connection

func (*Chart) Delete added in v0.2.0

func (c *Chart) Delete() error

Delete tells tiller to destroy a release

func (*Chart) GetInput added in v0.3.0

func (c *Chart) GetInput() []byte

GetInput gets the templated values file

func (*Chart) Install added in v0.2.0

func (c *Chart) Install() error

Install deploys a helm chart

func (*Chart) Lint added in v0.2.0

func (c *Chart) Lint(key string, in *util.Values) error

Lint validates the chart for required values some of which are parsed from values

func (*Chart) SetInput added in v0.2.0

func (c *Chart) SetInput(obj []byte)

SetInput adds the templated values file

func (*Chart) Status added in v0.2.0

func (c *Chart) Status() (bool, error)

Status returns the status of a release

func (*Chart) Upgrade added in v0.2.0

func (c *Chart) Upgrade() error

Upgrade tells tiller to upgrade a helm chart

type Tiller added in v0.3.0

type Tiller struct {
	// contains filtered or unexported fields
}

Tiller represents a helm client and open connection to tiller

func NewClient added in v0.3.0

func NewClient(k8s *kube.K8s, namespace, remote string) *Tiller

NewClient creates a new connection to tiller

func NewFakeClient added in v0.3.0

func NewFakeClient() *Tiller

NewFakeTiller establishes a fake helm client

func (*Tiller) Close added in v0.3.0

func (hl *Tiller) Close()

Close gracefully exits the connection to tiller

Jump to