Documentation
¶
Index ¶
- func Template(name string, input map[string]string, k8s *kube.K8s) ([]byte, error)
- type Depends
- type Jobs
- type Resource
- type Stage
- type Stages
- func (stg *Stages) BuildDepends(reverse bool) *Depends
- func (stg *Stages) Connect(k8s *kube.K8s, input util.Values, tillerName, tillerPort string) (func(), error)
- func (stg *Stages) Destroy(input util.Values, force, verbose bool)
- func (stg *Stages) Lint(in util.Values) (err error)
- func (stg *Stages) Run(input util.Values, force, verbose bool)
- func (stg *Stages) Until(input util.Values, force, verbose bool, target string)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Resource ¶ added in v0.2.0
type Resource interface {
Lint(string, *util.Values) error
Status() (bool, error)
Install() error
Upgrade() error
Delete() error
Connect(interface{})
SetInput([]byte)
GetInput() []byte
}
Resource is the thing to be created / destroyed
type Stage ¶
type Stage struct {
Depends []string `yaml:"depends"` // dependencies
Forget bool `yaml:"forget"` // install only
Input string `yaml:"input"` // template file
Jobs Jobs `yaml:"jobs"` // bash jobs
Kind string `yaml:"kind"` // type of deploy
Remove bool `yaml:"remove"` // delete instead
Requires util.Values `yaml:"requires"` // env requirements
Resource
}
Stage represents a single part of the deployment pipeline
func (*Stage) Backward ¶ added in v0.2.0
func (stg *Stage) Backward(key string, global util.Values, deps *Depends, force, verbose bool) error
Backward pass over the graph
func (*Stage) UnmarshalYAML ¶ added in v0.2.0
UnmarshalYAML allows us to determine the type of our resource
type Stages ¶ added in v0.2.0
Stages represents the complete workflow.
func (*Stages) BuildDepends ¶ added in v0.2.0
BuildDepends generates a dependency map
func (*Stages) Connect ¶ added in v0.2.0
func (stg *Stages) Connect(k8s *kube.K8s, input util.Values, tillerName, tillerPort string) (func(), error)
Connect links all of our stages to their required resources
Click to show internal directories.
Click to hide internal directories.