helm

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 23, 2019 License: GPL-3.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Bridge

type Bridge struct {
	// contains filtered or unexported fields
}

Bridge represents a helm client and open conn to tiller

func NewFakeBridge added in v0.2.0

func NewFakeBridge() *Bridge

NewFakeBridge establishes a fake helm client

func Setup

func Setup(k8s *kube.K8s, namespace, remote string) *Bridge

Setup creates a new connection to tiller

func (*Bridge) Close

func (b *Bridge) Close()

Close gracefully exits the connection to tiller

type Chart

type Chart struct {
	Name       string `yaml:"name"`       // name of chart
	Repository string `yaml:"repository"` // chart repository
	Version    string `yaml:"version"`    // chart version
	Release    string `yaml:"release"`    // release name
	Namespace  string `yaml:"namespace"`  // namespace
	Timeout    int64  `yaml:"timeout"`    // install / upgrade wait time
	Object     []byte
	*Bridge
}

Chart comprises the helm release

func (*Chart) Connect added in v0.2.0

func (c *Chart) Connect(bridge interface{})

Connect sets the established helm connection

func (*Chart) Delete added in v0.2.0

func (c *Chart) Delete() error

Delete tells tiller to destroy a release

func (*Chart) Install added in v0.2.0

func (c *Chart) Install() error

Install deploys a helm chart

func (*Chart) Lint added in v0.2.0

func (c *Chart) Lint(key string, in *util.Values) error

Lint validates the chart for required values some of which are parsed from values

func (*Chart) SetInput added in v0.2.0

func (c *Chart) SetInput(obj []byte)

SetInput adds the templated values file

func (*Chart) Status added in v0.2.0

func (c *Chart) Status() (bool, error)

Status returns the status of a release

func (*Chart) Upgrade added in v0.2.0

func (c *Chart) Upgrade() error

Upgrade tells tiller to upgrade a helm chart

Jump to